@@ -10,7 +10,6 @@
 # - Use a visual merge script to help with manual reconciliation (e.g., via kdiff3).
 #
 # TODO:
-# - Make stdout the default.
 # - Integrate merge heuristics for common issues.
 #   -- For example, accounting for changes flagged with comments:
 #      ## OLD: from regex import my_re
@@ -33,12 +32,12 @@ from mezcla import system
 BASENAME = "basename"
 BACKUP_DIR = "backup-dir"
 BACKUP_FILENAME = "backup-filename"
-FILENAME1 = "filename1"
-FILENAME2 = "filename2"
+MAIN_FILENAME = "main-filename"
+OTHER_FILENAME = "other-filename"
 QUIET = "quiet"
 USE_STDOUT = "stdout"
 SKIP_BASELINE = "skip-baseline"
-UPDATE_FILE1 = "update-file1"
+UPDATE_MAIN_FILE = "update-main-file"
 IGNORE_ERRORS = "ignore-errors"
 MERGE = system.getenv_text("MERGE", "/usr/bin/merge -p",
                            description="Command line for merge with output piping arg (e.g., -p)")
@@ -64,31 +63,30 @@ def get_numeric_timestamp(filename):
 
 class Script(Main):
     """Adhoc script processing class"""
-    filename1 = ""
-    filename2 = ""
+    main_filename = ""
+    other_filename = ""
     backup_filename = ""
     backup_dir = "./backup"
     basename = ""
     update_file1 = False
     skip_baseline = False
     quiet = False
-    use_stdout = False
+    use_stdout = None
     ignore_errors = False
 
     def setup(self):
         """Check results of command line processing"""
         debug.trace_fmtd(5, "Script.setup(): self={s}", s=self)
-        self.filename1 = self.get_parsed_argument(FILENAME1)
-        self.filename2 = self.get_parsed_argument(FILENAME2)
+        self.main_filename = self.get_parsed_argument(MAIN_FILENAME)
+        self.other_filename = self.get_parsed_argument(OTHER_FILENAME)
         self.backup_filename = self.get_parsed_option(BACKUP_FILENAME)
         self.backup_dir = self.get_parsed_option(BACKUP_DIR, self.backup_dir)
-        self.basename = self.get_parsed_option(BASENAME, self.filename1)
-        self.update_file1 = self.get_parsed_option(UPDATE_FILE1, self.update_file1)
+        self.basename = self.get_parsed_option(BASENAME, self.main_filename)
+        self.update_file1 = self.get_parsed_option(UPDATE_MAIN_FILE, self.update_file1)
         self.skip_baseline = self.get_parsed_option(SKIP_BASELINE, self.skip_baseline)
-        self.quiet = self.get_parsed_option(QUIET)
-        self.use_stdout = self.get_parsed_option(USE_STDOUT)
+        self.quiet = self.get_parsed_option(QUIET, self.quiet)
+        self.use_stdout = self.get_parsed_option(USE_STDOUT, self.update_file1)
         self.ignore_errors = self.get_parsed_option(IGNORE_ERRORS)
-        ## self.x = self.get_parsed_option(X)
         debug.trace_object(5, self, label="Script instance")
 
     def check_regular_file(self, filename):
@@ -103,16 +101,16 @@ class Script(Main):
         debug.trace_fmtd(5, "Script.run_main_step(): self={s}", s=self)
 
         # Validate input files
-        self.check_regular_file(self.filename1)
-        # TODO: if .../is_dir(self.filename2): self.filename2 = .../form_path(filename2, basename(filename2))
-        self.check_regular_file(self.filename2)
+        self.check_regular_file(self.main_filename)
+        # TODO: if .../is_dir(self.other_filename): self.other_filename = .../form_path(other_filename, basename(other_filename))
+        self.check_regular_file(self.other_filename)
 
         # Find the backup baseline if not specified
         if not self.backup_filename:
             EPSILON = 1e-6
-            timestamp1 = get_numeric_timestamp(self.filename1)
-            timestamp2 = get_numeric_timestamp(self.filename2)
-            min_timestamp = min(timestamp1, timestamp2) - EPSILON
+            main_timestamp = get_numeric_timestamp(self.main_filename)
+            other_timestamp = get_numeric_timestamp(self.other_filename)
+            min_timestamp = min(main_timestamp, other_timestamp) - EPSILON
 
             # Find most recent backup older than two files
             SEP = "\t"
@@ -128,31 +126,34 @@ class Script(Main):
 
             # If no suitable backup, use the older of the two files
             if ((not self.backup_filename) and self.skip_baseline):
-                self.backup_filename = self.filename1 if (timestamp1 < timestamp2) else self.filename2
+                self.backup_filename = self.main_filename if (main_timestamp < other_timestamp) else self.other_filename
         if not self.backup_filename:
             system.exit("Error: Unable to find baseline backup for {f1} ({ts1}) and {f2} ({ts2}) ",
-                        f1=self.filename1, ts1=get_timestamp(self.filename1),
-                        f2=self.filename2, ts2=get_timestamp(self.filename2))
+                        f1=self.main_filename, ts1=get_timestamp(self.main_filename),
+                        f2=self.other_filename, ts2=get_timestamp(self.other_filename))
         self.check_regular_file(self.backup_filename)
 
         # Do the merge and check for conflicts
+        # NOTE: Makes copy of each before merge in case inadvertantly clobbered (e.g., $TMP/filename1.copy)
         # TODO: produce report including diff listings of old vs. new
         system.create_directory(self.temp_base)
         temp_new_file = gh.form_path(self.temp_base, self.basename)
-        result = gh.run("{m} {f1} {b} {f2} > {new}", m=MERGE, f1=self.filename1,
-                        b=self.backup_filename, f2=self.filename2, new=temp_new_file)
+        gh.copy_file(self.main_filename, gh.form_path(self.temp_base, gh.basename(self.main_filename) + ".copy"))
+        gh.copy_file(self.other_filename, gh.form_path(self.temp_base, gh.basename(self.other_filename) + ".copy"))
+        result = gh.run("{m} {f1} {b} {f2} > {new}", m=MERGE, f1=self.main_filename,
+                        b=self.backup_filename, f2=self.other_filename, new=temp_new_file)
         if re.search(r"conflict in merge", result):
             system.print_stderr("Error in merge:\n\t{r}", r=gh.indent_lines(result))
         elif self.update_file1:
             if not self.quiet:
-                print("Updating {f1}", f1=self.filename1)
-            gh.rename_file(self.filename1, (self.filename1 + ".backup"))
-            gh.copy_file(temp_new_file, self.filename1)
+                print("Updating {f1}, after rename to {f1}.backup".format(f1=self.main_filename))
+            gh.rename_file(self.main_filename, (self.main_filename + ".backup"))
+            gh.copy_file(temp_new_file, self.main_filename)
         elif self.use_stdout:
             print(system.read_entire_file(temp_new_file))
         else:
             if not self.quiet:
-                print("Merge result:\n\t{r}".format(r=result))
+                print(f"Merge result:\n\t{result}")
                 debug.trace(4, f"See {temp_new_file}")
         return
 
@@ -166,12 +167,11 @@ if __name__ == '__main__':
         skip_input=True,
         manual_input=True,
         boolean_options=[(IGNORE_ERRORS, "Ignore errors in processing"),
-                         (UPDATE_FILE1, "Replace file1 with merged result"),
+                         (UPDATE_MAIN_FILE, f"Replace {MAIN_FILENAME} with merged result--be careful"),
                          (USE_STDOUT, "Use standard output for result"),
-                         ## TODO: (X, "..."),
                          (QUIET, "Omit status messages")],
-        positional_arguments=[FILENAME1, FILENAME2],
+        positional_arguments=[MAIN_FILENAME, OTHER_FILENAME],
         text_options=[(BACKUP_FILENAME, "Backup file for baseline"),
                       (BACKUP_DIR, "Backup directory"),
-                      (BASENAME, "Basename for backup check (if not filename1)")])
+                      (BASENAME, f"Basename for backup check--if not {MAIN_FILENAME}")])
     app.run()
