@@ -15,6 +15,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 """BERT finetuning runner."""
 
 # TPO: This is a version of the standard run_classifer.py from the bert
@@ -48,7 +49,7 @@ from bert import tokenization
 import tensorflow as tf
 
 # TPO: used just for start/end timestamps
-from mezcla import debug                # pylint: disable=unused-import
+from mezcla import debug
 # TPO: for error output (e.g., print_exception_info)
 from mezcla import system
 #
@@ -154,6 +155,7 @@ flags.DEFINE_integer(
     "num_tpu_cores", 8,
     "Only used if `use_tpu` is True. Total number of TPU cores to use.")
 
+UNKNOWN_LABEL = " "
 
 class InputExample(object):
   """A single training/test example for simple sequence classification."""
@@ -429,7 +431,7 @@ class MultiCatProcessor(DataProcessor):
       system.print_error_fmt("Problem reading category file {fn}: {exc}\n",
                               fn=category_file, exc=sys.exc_info())
     # Return as list of tokens with outer whitespace removed
-    cat_list = [c.strip() for c in cats.split("\n")]
+    cat_list = [c.strip() for c in cats.split("\n") if len(c)]
     return cat_list
 
   def _create_examples(self, lines, set_type):
@@ -440,11 +442,17 @@ class MultiCatProcessor(DataProcessor):
       try:
           # Only the test set has a header
           if set_type == "test" and i == 0:
+            debug.trace(6, f"Ignoring test header: {line}")
             continue
           guid = "%s-%s" % (set_type, i)
           if set_type == "test":
             text_a = tokenization.convert_to_unicode(line[1])
-            label = "0"
+            ## BAD: this assigns the first label under assumption all natural integers,
+            ## which works for hard-coded classes but not MultiCatProcessor
+            ##   label = "0"
+            ## TODO: rework to pass in the list of categories
+            # Assign unkwown label (so that later mappable to first label)
+            label = UNKNOWN_LABEL
           else:
             text_a = tokenization.convert_to_unicode(line[3])
             label = tokenization.convert_to_unicode(line[1])
@@ -472,7 +480,14 @@ def convert_single_example(ex_index, example, label_list, max_seq_length,
 
   label_map = {}
   for (i, label) in enumerate(label_list):
+    debug.assertion(label != UNKNOWN_LABEL)
     label_map[label] = i
+  ##
+  ## HACK: Treat unknown label as first (see _create_examples)
+  label_map[UNKNOWN_LABEL] = 0
+  ## TEMP: This is for non-MultiCatProcessor cases
+  if ("0" not in label_map):
+    label_map["0"] = 0
 
   tokens_a = tokenizer.tokenize(example.text_a)
   tokens_b = None
@@ -767,6 +782,7 @@ def model_fn_builder(bert_config, num_labels, init_checkpoint, learning_rate,
 
       def metric_fn(per_example_loss, label_ids, logits, is_real_example):
         predictions = tf.argmax(logits, axis=-1, output_type=tf.int32)
+        debug.trace_expr(6, logits, label_ids, predictions, is_real_example)
         accuracy = tf.metrics.accuracy(
             labels=label_ids, predictions=predictions, weights=is_real_example)
         loss = tf.metrics.mean(values=per_example_loss, weights=is_real_example)
