@@ -769,6 +769,18 @@ def remove_extension(filename, extension=None):
     return new_filename
 
 
+def get_extension(filename):
+    """Return extension in FILENAME"""
+    # EX: get_extension("document.pdf") => "pdf"
+    # EX: get_extension("it.abc.def") => "def"
+    # EX: get_extension("no-period") => ""
+    extension = ""
+    if "." in filename:
+        extension = filename.split(".")[-1]
+    debug.trace(5, f"get_extension({filename}) => {extension}")
+    return extension
+
+
 def file_exists(filename):
     """Returns True iff FILENAME exists"""
     does_exist = os.path.exists(filename)
@@ -943,7 +955,7 @@ def absolute_path(path):
     """Return resolved absolute pathname for PATH, as with Linux realpath command w/ --no-symlinks"""
     # EX: absolute_path("/etc/mtab").startswith("/etc")
     result = os.path.abspath(path)
-    debug.trace(7, f"real_path({path}) => {result}")
+    debug.trace(7, f"absolute_path({path}) => {result}")
     return result
 
 
@@ -982,35 +994,48 @@ def get_module_version(module_name):
     return version
 
 
-def intersection(list1, list2):
-    """Return intersection of LIST1 and LIST2"""
+def intersection(list1, list2, as_set=None):
+    """Return intersection of LIST1 and LIST2
+    Note: result is a list unless AS_SET specified
+    """
     # note: wrapper around set.intersection used for tracing
-    # EX: intersection([1, 2, 3, 4, 5], [2, 4]) => {1, 3, 5}
+    # EX: sorted(intersection([1, 2, 3, 4, 5], [2, 4])) => [1, 3, 5]
+    # EX: intersection([1, 2, 3, 4, 5], [2, 4], as_set=True)) => {1, 3, 5}
     # TODO: have option for returning list
     result = set(list1).intersection(set(list2))
+    if not as_set:
+        result = list(result)
     debug.trace_fmtd(7, "intersection({l1}, {l2}) => {r}",
                      l1=list1, l2=list2, r=result)
     return result
 
 
-def union(list1, list2):
-    """Return union of LIST1 and LIST2"""
+def union(list1, list2, as_set=None):
+    """Return union of LIST1 and LIST2
+    Note: result is a list unless AS_SET specified
+    """
+    # EX: union([1, 3, 5], [5, 7]) => [1, 3, 5, 7]
     # note: wrapper around set.union used for tracing
     result = set(list1).union(set(list2))
+    if not as_set:
+        result = list(result)
     debug.trace_fmtd(7, "union({l1}, {l2}) => {r}",
                      l1=list1, l2=list2, r=result)
     return result
 
 
-def difference(list1, list2):
-    """Return set difference from LIST1 vs LIST2, preserving order"""
+def difference(list1, list2, as_set=None):
+    """Return set difference from LIST1 vs LIST2, preserving order
+    Note: result is a list unless AS_SET specified
+    """
     # TODO: optmize (e.g., via a hash table)
     # EX: difference([5, 4, 3, 2, 1], [1, 2, 3]) => [5, 4]
-    # TODO: add option for returning set
     diff = []
     for item1 in list1:
         if item1 not in list2:
             diff.append(item1)
+    if as_set:
+        diff = set(diff)
     debug.trace_fmtd(7, "difference({l1}, {l2}) => {d}",
                      l1=list1, l2=list2, d=diff)
     return diff
